pub struct LayerClassifier { /* private fields */ }Expand description
Classifies file paths into architectural layers using glob patterns.
Implementations
Sourceimpl LayerClassifier
impl LayerClassifier
pub fn new(config: &LayersConfig) -> Self
Sourcepub fn classify(&self, path: &str) -> Option<ArchLayer>
pub fn classify(&self, path: &str) -> Option<ArchLayer>
Classify a file path into an architectural layer.
Sourcepub fn architecture_mode(&self, path: &str) -> ArchitectureMode
pub fn architecture_mode(&self, path: &str) -> ArchitectureMode
Get the architecture mode for a given file path. Checks overrides first (first scope match wins), falls back to global default.
Sourcepub fn is_cross_cutting(&self, path: &str) -> bool
pub fn is_cross_cutting(&self, path: &str) -> bool
Check if a path matches cross-cutting concern patterns.
Sourcepub fn is_cross_cutting_import(&self, import_path: &str) -> bool
pub fn is_cross_cutting_import(&self, import_path: &str) -> bool
Check if an import path matches cross-cutting concern patterns. Generates candidate paths to bridge Go-style import paths with file-path-style globs.
Sourcepub fn classify_import(&self, import_path: &str) -> Option<ArchLayer>
pub fn classify_import(&self, import_path: &str) -> Option<ArchLayer>
Classify an import path string into an architectural layer.